@@ -10,9 +10,10 @@
 // followed only by non-alphanumerics, then "(X)" gets removed.
 static QString removeReducedCJKAccMark(const QString &label, int pos)
 {
-    if (pos > 0 && pos + 1 < label.length()
-            && label[pos - 1] == QLatin1Char('(') && label[pos + 1] == QLatin1Char(')')
-            && label[pos].isLetterOrNumber()) {
+    if (pos > 0 && pos + 1 < label.length() //
+        && label[pos - 1] == QLatin1Char('(') //
+        && label[pos + 1] == QLatin1Char(')') //
+        && label[pos].isLetterOrNumber()) {
         // Check if at start or end, ignoring non-alphanumerics.
         int len = label.length();
         int p1 = pos - 2;
@@ -69,7 +70,7 @@ QString removeAcceleratorMarker(const QString &label_)
     // ampersand beforehand.
     if (!accmarkRemoved) {
         bool hasCJK = false;
-        for (const QChar c : label) {
+        for (const QChar c : qAsConst(label)) {
             if (c.unicode() >= 0x2e00) { // rough, but should be sufficient
                 hasCJK = true;
                 break;
